pub type DialogError = Error;Available on (crate features
xdg-portal or rfd) and crate feature xdg-portal only.Aliased Type
pub enum DialogError {
Response(ResponseError),
Portal(PortalError),
Zbus(Error),
NoResponse,
ParseError(&'static str),
IO(Error),
InvalidAppID,
NulTerminated(usize),
RequiresVersion(u32, u32),
PortalNotFound(OwnedInterfaceName),
UnexpectedIcon,
}Variants
Response(ResponseError)
The portal request didn’t succeed.
Portal(PortalError)
Something Failed on the portal request.
Zbus(Error)
A zbus::fdo specific error.
NoResponse
A signal returned no response.
ParseError(&'static str)
Failed to parse a string into an enum variant
IO(Error)
Input/Output
InvalidAppID
Invalid AppId
See https://developer.gnome.org/documentation/tutorials/application-id.html#rules-for-application-ids
NulTerminated(usize)
An error indicating that an interior nul byte was found
RequiresVersion(u32, u32)
Requires a newer interface version.
The inner fields are the required version and the version advertised by the interface.
PortalNotFound(OwnedInterfaceName)
Returned when the portal wasn’t found. Either the user has no portals frontend installed or the frontend doesn’t support the used portal.
UnexpectedIcon
An error indicating that a Icon::Bytes was expected but wrong type was passed